"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createFilesTypeDefs = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _renderFields = require("@webiny/api-headless-cms/utils/renderFields");
var _renderInputFields = require("@webiny/api-headless-cms/utils/renderInputFields");
var _renderListFilterFields = require("@webiny/api-headless-cms/utils/renderListFilterFields");
var _renderSortEnum = require("@webiny/api-headless-cms/utils/renderSortEnum");
const removeFieldRequiredValidation = field => {
  if (field.validation) {
    field.validation = field.validation.filter(validation => validation.name !== "required");
  }
  if (field.listValidation) {
    field.listValidation = field.listValidation.filter(v => v.name !== "required");
  }
  return field;
};
const createUpdateFields = fields => {
  return fields.reduce((collection, field) => {
    collection.push(removeFieldRequiredValidation((0, _objectSpread2.default)({}, field)));
    return collection;
  }, []);
};
const createFilesTypeDefs = params => {
  const {
    model,
    models,
    plugins: fieldTypePlugins
  } = params;
  const {
    fields
  } = model;
  const fieldTypes = (0, _renderFields.renderFields)({
    models,
    model,
    fields,
    type: "manage",
    fieldTypePlugins
  });
  const inputCreateFields = (0, _renderInputFields.renderInputFields)({
    models,
    model,
    fields,
    fieldTypePlugins
  });
  const inputUpdateFields = (0, _renderInputFields.renderInputFields)({
    models,
    model,
    fields: createUpdateFields(fields),
    fieldTypePlugins
  });
  const listFilterFieldsRender = (0, _renderListFilterFields.renderListFilterFields)({
    model,
    fields: model.fields,
    type: "manage",
    fieldTypePlugins,
    excludeFields: ["entryId", "status"]
  });
  const excludeFromSorterts = ["tags", "aliases"];
  const sortEnumRender = (0, _renderSortEnum.renderSortEnum)({
    model,
    fields: model.fields.filter(field => !excludeFromSorterts.includes(field.fieldId)),
    fieldTypePlugins,
    sorterPlugins: []
  });
  return (/* GraphQL */`
        ${fieldTypes.map(f => f.typeDefs).join("\n")}

        type FmFile {
            id: ID!
            savedOn: DateTime!
            createdOn: DateTime!
            createdBy: FmCreatedBy!
            src: String
            ${fieldTypes.map(f => f.fields).join("\n")}
        }

        ${inputCreateFields.map(f => f.typeDefs).join("\n")}

        input FmFileCreateInput {
            id: ID!
            ${inputCreateFields.map(f => f.fields).join("\n")}
        }

        input FmFileUpdateInput {
            ${inputUpdateFields.map(f => f.fields).join("\n")}
        }

        type FmFileResponse {
            data: FmFile
            error: FmError
        }

        input FmFileListWhereInput {
            ${listFilterFieldsRender}
            AND: [FmFileListWhereInput!]
            OR: [FmFileListWhereInput!]
        }

        type FmFileListResponse {
            data: [FmFile!]
            error: FmError
            meta: FmListMeta
        }

        enum FmFileListSorter {
            ${sortEnumRender}
        }

        input FmTagsListWhereInput {
            createdBy: String
            tags_startsWith: String
            tags_not_startsWith: String
        }

        type FmTag {
            tag: String!
            count: Number!
        }

        type FmTagsListResponse {
            data: [FmTag!]
            error: FmError
        }

        type FmCreateFilesResponse {
            data: [FmFile!]
            error: FmError
        }
            
        type FmFileModelResponse {
            data: JSON
            error: FmError
        }

        extend type FmQuery {
            getFileModel: FmFileModelResponse!
            getFile(id: ID!): FmFileResponse!
            listFiles(
                search: String
                where: FmFileListWhereInput
                limit: Int
                after: String
                sort: [FmFileListSorter!]
            ): FmFileListResponse!
            listTags(where: FmTagsListWhereInput): FmTagsListResponse!
        }

        extend type FmMutation {
            createFile(data: FmFileCreateInput!): FmFileResponse!
            createFiles(data: [FmFileCreateInput!]!): FmCreateFilesResponse!
            updateFile(id: ID!, data: FmFileUpdateInput!): FmFileResponse!
            deleteFile(id: ID!): FmBooleanResponse!
        }
    `
  );
};
exports.createFilesTypeDefs = createFilesTypeDefs;